--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersCropPrices by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- All rights reserved.
-- Version 1.0.0.0
-- 30.11.2018 - 20.03.2019

-- Names for FillTypes

-- WHEAT BARLEY OAT CANOLA SUNFLOWER SOYBEAN MAIZE POTATO SUGARBEET OILSEEDRADISH
-- MANURE SEEDS FORAGE FORAGE_MIXING CHAFF WOODCHIPS SILAGE
-- STRAW GRASS_WINDROW DRYGRASS_WINDROW SUGARCANE FERTILIZER PIGFOOD LIME
-- WOOL TREESAPLINGS EGG
-- MILK FUEL WATER DIESEL DEF
-- LIQUIDFERTILIZER HERBICIDE
-- CHAFF GRASS_WINDROW
-- LIQUIDMANURE DIGESTATE
-- COW_TYPE_BRAHMAN_GREY COW_TYPE_BRAHMAN_LIGHT_BROWN COW_TYPE_BRAHMAN_WHITE
-- COW_TYPE_BRAHMAN_BROWN COW_TYPE_BROWN COW_TYPE_BROWN_WHITE COW_TYPE_BLACK
-- COW_TYPE_BLACK_WHITE
-- SHEEP_TYPE_WHITE SHEEP_TYPE_BROWN SHEEP_TYPE_BLACK_WHITE SHEEP_TYPE_BLACK
-- PIG_TYPE_RED PIG_TYPE_WHITE PIG_TYPE_BLACK_WHITE PIG_TYPE_BLACK
-- CHICKEN_TYPE_BLACK CHICKEN_TYPE_WHITE CHICKEN_TYPE_BROWN CHICKEN_TYPE_ROOSTER

--[[
Crop Prices

	Crop prices are averaged prices over 3-5 years for an EU country or a US agricultural region.

	There are no information about prices on Cotton from EUROSTAT. The average US sell price is used.
	In Europe, cotton is only grown in Bulgaria, Greece and Spain.

Crop income ranking
	
	The script also computes the income per hectare of all crops by multiplying the crop yield and the
	crop sell price. This information will tell which crop statistically gives the biggest earning in that  
	country or agricultural region. 
	
	Information is printed to the log file.

]]--


RealNumbersCropPrices = {};


function RealNumbersCropPrices:loadMap(name)
	local currency = "€";	-- or  "$" or "£"
    local textWidth = 40; 	-- text width in log file
    local iFillType = 0;
	local iFruitType = 0;
	local Crop = "Empty";
	local idx = 0;
	local price = 0;
	local yield = 0;
	local massScale = 1000;
	local gameCorrection = RN.fieldWorkbaseYieldAdjustment;	-- scale factor to obtain base yield from bonus yield
	local isDebug = RN.isDebug;  -- Change to False when not debugging

	local Fruits = RN.Fruits;
	local cropDensity = RN.cropDensity;
	local cropPricePer100kg = RN.cropPricePer100kg;
	local otherFruits = RN.otherFruits;
	local otherCropDensity = RN.otherCropDensity;
	local otherCropPricePer100kg = RN.otherCropPricePer100kg;

	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then 
        currency = "€";
	elseif gameMoneyUnit == 2 then 
        currency = "$";
	elseif gameMoneyUnit == 3 then 
        currency = "£";
	end;

	print("FS19_RealLifeNumbers: RealNumbersCropPrices active")
	
	if isDebug then print("\nRealNumbersCropPrices Debug Report Start \n") end;


-- WHEAT

    idx = 1;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('WHEAT');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;
	
--BARLEY

    idx = 2;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('BARLEY');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;


--OAT

	idx = 3;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('OAT');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;

--COTTON

	idx = 4;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('COTTON');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;



--CANOLA

	idx = 5;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('CANOLA');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;


--SUNFLOWER

	idx = 6;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('SUNFLOWER');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;


--SOYBEAN

	idx = 7;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('SOYBEAN');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
     g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;

--MAIZE

	idx = 8;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('MAIZE');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;

--POTATO

	idx = 9;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('POTATO');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
     g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;

--SUGARBEET

	idx = 10;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('SUGARBEET');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;

--OILSEEDRADISH

	idx = 11;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('OILSEEDRADISH');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;


--POPLAR

	idx = 12;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('POPLAR');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;

--GRASS	
	
	idx = 13;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('GRASS');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;	
	
--DRYGRASS

	idx = 14;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('DRYGRASS');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFillType = g_fillTypeManager:getFillTypeIndexByName('DRYGRASS_WINDROW');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		print(" ");
	end;
	
--SUGARCANE

	idx = 15;
    Crop = Fruits[idx];
	price = cropDensity[idx]*cropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('SUGARCANE');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = cropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	iFruitType = g_fruitTypeManager:getFruitTypeIndexByFillTypeIndex(iFillType);
	yieldPerHa = 10000 * g_currentMission.fruitTypeManager.fruitTypes[iFruitType].literPerSqm/gameCorrection;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",cropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		myPrint(Crop.." pricePerHa",yieldPerHa * price,textWidth,currency.."/Ha");
		print(" ");
	end;

--STRAW

	idx = 3;
    Crop = otherFruits[idx];
	price = otherCropDensity[idx]*otherCropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('STRAW');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = otherCropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",otherCropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		print(" ");
	end;

--SILAGE

	idx = 4;
    Crop = otherFruits[idx];
	price = otherCropDensity[idx]*otherCropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('SILAGE');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = otherCropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
 	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",otherCropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		print(" ");
	end;



--WOODCHIPS

	idx = 5;
    Crop = otherFruits[idx];
	price = otherCropDensity[idx]*otherCropPricePer100kg[idx]/100;
    iFillType = g_fillTypeManager:getFillTypeIndexByName('WOODCHIPS');
	g_currentMission.fillTypeManager.fillTypes[iFillType].massPerLiter = otherCropDensity[idx]/massScale;
    g_currentMission.fillTypeManager.fillTypes[iFillType].pricePerLiter = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].previousHourPrice = price;
	g_currentMission.fillTypeManager.fillTypes[iFillType].startPricePerLiter = price;
	if isDebug then
		myPrint(Crop.." fillTypeIndex",iFillType,textWidth," ");
		myPrintFloat(Crop.." massPerLiter",otherCropDensity[idx],textWidth," kg/L");
		myPrint(Crop.." pricePer1000Liter",1000*price,textWidth,currency.."/1000 L");
		print(" ");
	end;

	if isDebug then print("\nRealNumbersCropPrices Debug Report End \n") end;

end;


function RealNumbersCropPrices:keyEvent(unicode, sym, modifier, isDown)
end;
function RealNumbersCropPrices:update(dt)
end;
function RealNumbersCropPrices:draw()
end;
function RealNumbersCropPrices:deleteMap()
end;
function RealNumbersCropPrices:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersCropPrices);
