--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersFieldInfo by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- All rights reserved.
-- Version 1.0.0.0
-- 30.11.2018 - 20.03.2019

-- Names for FillTypes

-- WHEAT BARLEY OAT CANOLA SUNFLOWER SOYBEAN MAIZE POTATO SUGARBEET OILSEEDRADISH
-- MANURE SEEDS FORAGE FORAGE_MIXING CHAFF WOODCHIPS SILAGE
-- STRAW GRASS_WINDROW DRYGRASS_WINDROW SUGARCANE FERTILIZER PIGFOOD LIME
-- WOOL TREESAPLINGS EGG
-- MILK FUEL WATER DIESEL DEF
-- LIQUIDFERTILIZER HERBICIDE
-- CHAFF GRASS_WINDROW
-- LIQUIDMANURE DIGESTATE
-- COW_TYPE_BRAHMAN_GREY COW_TYPE_BRAHMAN_LIGHT_BROWN COW_TYPE_BRAHMAN_WHITE COW_TYPE_BRAHMAN_BROWN
-- COW_TYPE_BROWN COW_TYPE_BROWN_WHITE COW_TYPE_BLACK COW_TYPE_BLACK_WHITE
-- SHEEP_TYPE_WHITE SHEEP_TYPE_BROWN SHEEP_TYPE_BLACK_WHITE SHEEP_TYPE_BLACK
-- PIG_TYPE_RED PIG_TYPE_WHITE PIG_TYPE_BLACK_WHITE PIG_TYPE_BLACK
-- CHICKEN_TYPE_BLACK CHICKEN_TYPE_WHITE CHICKEN_TYPE_BROWN CHICKEN_TYPE_ROOSTER

--[[
Field info

	This script provides information on size, price, ownership and crop on each field on the map.
	This information is needed to plan what fields to buy to meet animal feed needs.

Invocation

	This script needs to be executed when the map is finished loading. For this reason, the mod user
	needs to trigger it by pressing LeftAlt-rf.

Harvest work

	The script also adds up the total area owned to be harvested with various harvesters or headers.
	This information will help decide on the size of harvesters and headers to buy.

	All information is printed to the log file.
]]--

RealNumbersFieldInfo = {};

function myPrintFieldInfo(Id, landArea, fieldArea, landPrice, currency, owned, fruitName)
	print(string.format("Field %2.0f: Landarea = %4.1f ha, Fieldarea = %4.1f ha, Price = %7.0f %s, Is owned: %s, Fruittype: %s", Id*1.0, landArea, fieldArea, landPrice*1.0, tostring(currency), tostring(owned), tostring(fruitName)));
end;
function myPrintFieldInfo2(Id, landArea, fieldArea, landPrice, currency, owned, fruitName)
	print(string.format("Field %2.0f: Landarea = %4.1f ha, Fieldarea = %4.1f ha, Price = %7.0f %s, %s, Fruittype: %s", Id*1.0, landArea, fieldArea, landPrice*1.0, currency, tostring(owned), tostring(fruitName)));
end;
function myPrintFieldInfo3(text, number, textWidth, unit)
	print(string.format("%s =  %8.1f %s", text..string.rep(" ",textWidth-string.len(text)),number, unit));
end;
function myPrintFieldInfo4(number, number2)
	print(string.format("Field %2.0f: Usability ratio = %8.4f", number, number2));
end;

function RealNumbersFieldInfo:loadMap()
	print("\nFS19_RealLifeNumbers: RealNumbersFieldInfo active,  press lAlt-rf\n");
end;

function RealNumbersFieldInfo:keyEvent(unicode, sym, modifier, isDown)
	local currency = " ";
	local isDebug = RN.isDebug;
	local isDebug2 = false;
	local isDebug2 = false;
	local modName = "FS19_RealLifeNumbers_DE";
	local RealLifeNumbersDirectory = g_modNameToDirectory[modName];
	local moddir = string.gsub(RealLifeNumbersDirectory, "/"..modName, "");
    local textWidth = 40;
	local ownedCropHa = {};
	local usabilityRatio = {};
	local Fruits = RN.Fruits;
	local grainCrops = "WHEAT BARLEY OAT CANOLA SOYBEAN";
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end

	ownedCropHa.grain = 0;									--grain crops harvested with grain header
	ownedCropHa.rowgrain = 0;								--grain crop harvested with corn header
	ownedCropHa.potato = 0;									--area harvested with with potato harvester
	ownedCropHa.sugarbeet = 0;								--area harvested with with sugarbeet harvester
	ownedCropHa.grass = 0;									--area mowed with grass mower
	ownedCropHa.cotton = 0;
	ownedCropHa.sugarcane = 0;
	ownedCropHa.farmlandtotal = 0;
	ownedCropHa.fieldstotal = 0;



	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_f) then

		if g_currentMission.missionInfo.savegameDirectory ~= nil then

			print("\nRealNumbersFieldInfo Debug Report Start\n")
			print("Left Alt-rf pressed\n");
			print("Map                   : "..g_currentMission.missionInfo.map.title.." "..g_currentMission.missionInfo.displayName);
			print("Money                 : "..g_currentMission.missionInfo.money);

			local gameLevel = g_currentMission.missionInfo.economicDifficulty;
			print("Economic difficulty   : "..gameLevel);
			print("Sell price multiplier : "..g_currentMission.economyManager.PRICE_MULTIPLIER[gameLevel]);
			print("Buy price multiplier  : "..g_currentMission.economyManager.COST_MULTIPLIER[gameLevel]);
			print("Current game day      : "..g_currentMission.environment.currentDay);
			local hour = g_currentMission.environment.currentHour;
			local minute = g_currentMission.environment.currentMinute;
			print("Time of day           : "..hour..":"..minute);
			print(" ");


			if g_fieldManager.fields ~= nil then
				print("Mean land purchase price = "..g_farmlandManager.pricePerHa.." "..currency.."/ha");
				print("Mean land rent price = "..RN.rentPricePerHa.." "..currency.."/ha");
				for k,field in pairs(g_fieldManager.fields) do
					local farmland = field.farmland;
					local farmlandId = farmland.id;
					local fieldId = field.fieldId;
					local fieldArea = field.fieldArea;
					local farmlandArea = farmland.areaInHa;
					local farmlandPrice = farmland.price;
					local farmlandIsOwned = farmland.isOwned;
					usabilityRatio[k] = fieldArea/farmlandArea;

					local fieldFruitName = "Undefined";
					local fieldFruitType = field.fruitType;
					if fieldFruitType == nil then
						fieldFruitName = "Undefined";
						if farmlandIsOwned then
							ownedCropHa.farmlandtotal = ownedCropHa.farmlandtotal + farmlandArea;
							ownedCropHa.fieldstotal = ownedCropHa.fieldstotal + fieldArea;
							if RN.fieldStatus[fieldId] == " For sale" then RN.fieldStatus[fieldId] = " Owned   "; end;
							if RN.fieldStatus[fieldId] == " For rent" then RN.fieldStatus[fieldId] = " Rented  "; end;
						end;
					else
						fieldFruitName = Fruits[fieldFruitType];
						if farmlandIsOwned then
							ownedCropHa.farmlandtotal = ownedCropHa.farmlandtotal + farmlandArea;
							ownedCropHa.fieldstotal = ownedCropHa.fieldstotal + fieldArea;
							if RN.fieldStatus[fieldId] == " For sale" then RN.fieldStatus[fieldId] = " Owned   "; end;
							if RN.fieldStatus[fieldId] == " For rent" then RN.fieldStatus[fieldId] = " Rented  "; end;
							local i = 0;
							i,j = string.find(grainCrops,fieldFruitName);
							if i ~= nil then
								ownedCropHa.grain = ownedCropHa.grain + fieldArea;
							elseif (fieldFruitName == "MAIZE") or (fieldFruitName == "Sunflower") then
								ownedCropHa.rowgrain = ownedCropHa.rowgrain + fieldArea;
							elseif fieldFruitName == "POTATO" then
								ownedCropHa.potato = ownedCropHa.potato + fieldArea;
							elseif fieldFruitName == "SUGARBEET" then
								ownedCropHa.sugarbeet = ownedCropHa.sugarbeet + fieldArea;
							elseif fieldFruitName == "GRASS" then
								ownedCropHa.grass = ownedCropHa.grass + fieldArea;
							elseif fieldFruitName == "COTTON" then
								ownedCropHa.cotton = ownedCropHa.cotton + fieldArea;
							elseif fieldFruitName == "SUGARCANE" then
								ownedCropHa.sugarcane = ownedCropHa.sugrcane + fieldArea;
							end;
						end;
					end;
					myPrintFieldInfo2(fieldId, farmlandArea, fieldArea, farmlandPrice, currency, RN.fieldStatus[fieldId], fieldFruitName);
				end;
			end;
			print("\n---Owned land and crop area---\n")
			myPrintFieldInfo3("Total farmland area owned/rented",ownedCropHa.farmlandtotal,textWidth," Ha");
			myPrintFieldInfo3("Total field area owned/rented",ownedCropHa.fieldstotal,textWidth," Ha");
			myPrintFieldInfo3("Grain crop area",ownedCropHa.grain,textWidth," Ha");
			myPrintFieldInfo3("Row grain crop area",ownedCropHa.rowgrain,textWidth," Ha");
			myPrintFieldInfo3("Potato area",ownedCropHa.potato,textWidth," Ha");
			myPrintFieldInfo3("Sugarbeet area",ownedCropHa.sugarbeet,textWidth," Ha");
			myPrintFieldInfo3("Grass area",ownedCropHa.grass,textWidth," Ha");
			myPrintFieldInfo3("Cotton area",ownedCropHa.cotton,textWidth," Ha");
			myPrintFieldInfo3("Sugarcane area",ownedCropHa.sugarcane,textWidth," Ha\n");

			if g_fieldManager.fields ~= nil then
				for k,field in pairs(g_fieldManager.fields) do
					myPrintFieldInfo4(k, usabilityRatio[k]);
				end;
			end;
			print("\nRealNumbersFieldInfo Debug Report End \n");
		else
			print("No save game yet. Save the game, quit and reload");
		end;
	end;
end;
function RealNumbersFieldInfo:update(dt)
end;
function RealNumbersFieldInfo:draw()
end;
function RealNumbersFieldInfo:deleteMap()
end;
function RealNumbersFieldInfo:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersFieldInfo);
