--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersInitialization by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- All rights reserved.
-- Version 1.0.0.0
-- 30.11.2018 - 20.03.2019



RealNumbersInitialization = {};

-- Global print functions. Can be used in all scripts.

function myPrint(text, number, textWidth, unit)
	print(string.format("%s =  %8.0f %s", text..string.rep(" ",textWidth-string.len(text)),number,"    "..unit));
end;
function myPrintFloat(text, number, textWidth, unit)
	print(string.format("%s =  %12.4f %s", text..string.rep(" ",textWidth-string.len(text)),number, unit));
end;



function RealNumbersInitialization:loadMap(name)


	RN = {};										-- Global RealNumbers parameters
	RN.isDebug                        = true;		-- if true: prints output to log file
	RN.fieldWorkbaseYieldAdjustment   = 1/2;   		-- Scale down from desired yield to base yield (no lime and no ferilizer)
	RN.gameLevel                      = {};			-- Global game level correction factors	 
	RN.gameLevel.cropYieldCorrection  = 1;  		-- Crop yield is only 50% of specified if playing on economic level HARD
	RN.gameLevel.sellPriceMultiplier  = {3,1.8,1}; 	-- economic difficulty levels 1, 2, and 3
	RN.gameLevel.buyPriceMultiplier   = {0.4,0.7,1};-- economic difficulty levels 1, 2, and 3
	RN.DIRECT_SELL_MULTIPLIER         = 1.2000;		-- Presumably added sales price for selling used equipment at dealers shop			
	RN.DEFAULT_RUNNING_LEASING_FACTOR = 0.0021; 	-- Lease/hour as fraction of price. Ingame = 0.021. Change has no effect.
	RN.PER_DAY_LEASING_FACTOR         = 0.0010;		-- The change has no effect
	RN.DEFAULT_LEASING_DEPOSIT_FACTOR = 0.0020;		-- The change has no effect
	RN.MAX_GREAT_DEMANDS              = 3.0000;		-- Found he parameter, is not used for anything yet.
	
	
	local isDebug  = RN.isDebug;
	local isDebug2 = false;
  
-- mission rewards. Guessed numbers. Meassure your own missionHaPerHour and enter your personal work capacity.

	RN.missionTypes      = { "mow_bale", "plow" , "cultivate", "sow", "harvest", "weed", "spray", "fertilize", "transport"};
	RN.missionHaPerHour  = {    1,          4,          6,       2,       5,        8,      24,         24,         1     };                  
	RN.missionPayPerHour = 10; -- mission wage per hour

-- Helper salary can be set by the mod helperAdmin by apuehri/LS-Modcompany. Salary options may have to be changed inside the file
-- gui/haGuiGeneralSettingsFrame.lua

	RN.pigs    = {};
	RN.cows    = {};
	RN.sheep   = {};
	RN.chicken = {};
	RN.horses  = {};
	
-- FillType indices

--[[
	1 :: UNKNOWN, 2 :: WHEAT, 3 :: BARLEY, 4 :: OAT, 5 :: CANOLA, 6 :: SUNFLOWER, 7 :: SOYBEAN, 8 :: MAIZE
	9 :: POTATO, 10 :: SUGARBEET, 11 :: COTTON, 12 :: SUGARCANE, 13 :: SEEDS, 14 :: EGG, 15 :: WOOL, 16 :: MILK
	17 :: FUEL, 18 :: WATER, 19 :: FORAGE, 20 :: FORAGE_MIXING, 21 :: CHAFF, 22 :: TREESAPLINGS, 23 :: WOODCHIPS
	24 :: SILAGE, 25 :: OILSEEDRADISH, 26 :: POPLAR, 27 :: GRASS, 28 :: GRASS_WINDROW, 29 :: DRYGRASS,
	30 :: DRYGRASS_WINDROW, 31 :: STRAW, 32 :: DIESEL, 33 :: DEF, 34 :: AIR, 35 :: ROUNDBALE, 36 :: ROUNDBALE_GRASS
	37 :: ROUNDBALE_DRYGRASS, 38 :: ROUNDBALE_WHEAT, 39 :: ROUNDBALE_BARLEY, 40 :: SQUAREBALE, 41 :: SQUAREBALE_WHEAT
	42 :: SQUAREBALE_BARLEY, 43 :: FERTILIZER, 44 :: LIQUIDFERTILIZER, 45 :: MANURE, 46 :: LIQUIDMANURE
	47 :: DIGESTATE, 48 :: PIGFOOD, 49 :: TARP, 50 :: LIME, 51 :: HERBICIDE, 52 :: WEED, 53 :: HORSE_TYPE_BEIGE
	54 :: HORSE_TYPE_BLACK, 55 :: HORSE_TYPE_BROWN, 56 :: HORSE_TYPE_BROWN_WHITE, 57 :: HORSE_TYPE_DARK_BROWN
	58 :: HORSE_TYPE_GREY, 59 :: HORSE_TYPE_LIGHT_BROWN, 60 :: HORSE_TYPE_RED_BROWN, 61 :: COW_TYPE_BROWN
	62 :: COW_TYPE_BROWN_WHITE, 63 :: COW_TYPE_BLACK, 64 :: COW_TYPE_BLACK_WHITE, 65 :: COW_TYPE_BRAHMAN_BROWN
	66 :: COW_TYPE_BRAHMAN_WHITE, 67 :: COW_TYPE_BRAHMAN_LIGHT_BROWN, 68 :: COW_TYPE_BRAHMAN_GREY
	69 :: SHEEP_TYPE_WHITE, 70 :: SHEEP_TYPE_BROWN, 71 :: SHEEP_TYPE_BLACK_WHITE, 72 :: SHEEP_TYPE_BLACK
	73 :: PIG_TYPE_RED, 74 :: PIG_TYPE_WHITE, 75 :: PIG_TYPE_BLACK_WHITE, 76 :: PIG_TYPE_BLACK
	77 :: CHICKEN_TYPE_BLACK, 78 :: CHICKEN_TYPE_WHITE, 79 :: CHICKEN_TYPE_BROWN, 80 :: CHICKEN_TYPE_ROOSTER
--]]
-- FruitType indices

	-- WHEAT :: 1, BARLEY :: 2, OAT :: 3, COTTON :: 4, CANOLA :: 5, SUNFLOWER :: 6,
	-- SOYBEAN :: 7, MAIZE :: 8, POTATO :: 9, SUGARBEET :: 10, OILSEEDRADISH :: 11,
	-- POPLAR :: 12, GRASS :: 13, DRYGRASS :: 14, SUGARCANE :: 15, WEED :: 16

-- Hereunder are all major parameter values in FS19_RealLifeNumbers.
-- Each value can be changed. But the structure and order must remain unchanged. Additional numbers cannot be appended. 	
	
-- Crop yield, seed usage and sell price

	RN.Fruits =            {   "WHEAT", "BARLEY", "OAT", "COTTON", "CANOLA", "SUNFLOWER", "SOYBEAN", "MAIZE", "POTATO", "SUGARBEET", "OILSEEDRADISH", "POPLAR", "GRASS", "DRYGRASS", "SUGARCANE", "WEED"};
    RN.cropDensity =       {    0.772,   0.618,   0.412,   0.23,     0.644,     0.412,     0.772,     0.721,     0.75,      0.70,         0.80,         0.4,      0.46,      0.16,      0.70,     0.46}; 	-- kg/liter
	RN.cropYield =         {    45.95,   36.94,   23.94,  12.70,    17.00,      16.00,     34.82,     112.6,    383.3,     356.2,        28.50,        6.50,    156.53,     54.47,     810.2,      0.0}; 	-- GEO 100 kg/ha
	RN.yieldRange =        {    0.197,   0.201,   0.212,  0.682,     0.317,     0.524,     0.554,     0.449,    0.094,     0.071,        0.445,           0,     0.218,     0.218,         0,        0};	-- GEO 2 standard deviations/mean
	RN.seedDensity =       {    0.772,   0.618,   0.412,  0.412,     0.644,     0.412,     0.772,     0.721,     0.75,     0.435,         0.35,         0.4,     0.772,      0.16,      0.70,        0};	-- kg/liter
	RN.TSM =               {       40,      40,      35,      0,       2.5,       126,       160,       380,    36000,        13,           15,           0,       1.4,         0,    250000,        0};   	-- Thousand seed mass in gram
	RN.plantsPerSqm =      {      250,     210,     250,      0,       100,         6,        30,         5,        4,        18,           70,           0,       550,         0,         4,        0};   	-- plants per sqm
	RN.Germination =       {       90,      90,      90,      0,        90,        80,        90,        90,       80,        80,           70,           1,        90,         1,        86,        1};   	-- Germinaion perentage
	RN.seedPricePer100kg = {    52.00,   55.00,   62.00,  17.00,     36.00,    150.00,    200.00,    241.00,    32.00,     35.00,       282.00,         1.0,       350,         0,      4.60,        0};	-- GEO price per 100 kg
	RN.cropPricePer100kg = {    16.87,   18.61,   21.01, 0.6170,     36.71,     44.49,     35.94,     14.41,    23.99,     2.617,          0.0,        10.0,         5,     11.55,     3.125,        0};  	-- GEO https://www.dunns-ls.co.uk/markets/
	RN.seederCalibration = {    0.845,   1.000,   1.000,  1.000,     1.000,     1.000,     1.000,     1.000,    1.000,     1.000,        1.000,       1.000,     1.000,     1.000,     1.000,    1.000};	-- calibration factor for seeder and planters  
	
	
-- Other products

	RN.otherFruits =             {   "GRASS_WINDROW", "DRYGRASS_WINDROW", "STRAW", "SILAGE", "WOODCHIPS"};
    RN.otherCropDensity =        {        0.46,              0.16,          0.13,    0.6,        0.3    }; 	-- kg/liter
	RN.otherCropPricePer100kg =  {         5.0,             11.55,          7.47,    5.0,       13.5    };  -- GEO 


-- Spraying

	RN.sprayNames =              {  "FERTILIZER", "LIQUIDFERTILIZER", "MANURE", "LIQUIDMANURE", "DIGESTATE", "LIME", "HERBICIDE"}
	RN.sprayTypeDensity =        {       0.8,            0.9,           0.6,        0.9,            0.9,       1.2,      1.0    };		-- kg/liter
	RN.sprayWidth =              {        24,             36,            24,         12,             12,        18,       36    };		-- m
	RN.workingSpeed =            {        20,             12,            20,         17,             17,        20,       12    };		-- kph
    RN.sprayerCapacity =         {      3200,           4380,         22900,      15780,          15780,     18950,     6000    }; 		-- Liters       
	RN.sprayCalibrationFactor =  {     1.000,          1.000,         1.000,      1.000,          1.000,     0.778,    1.000    };  
	
	RN.soilType =                       2;		-- 1: Sands and loamy sands: 2: Sandy loams and silt loam; 3: Clay loams and clay
	RN.soilCurrentpH =                  6;		-- determinant for lime application rate
	RN.soilTargetpH =                 6.7;		-- determinant for lime application rate
	RN.limeNV =                        50;		-- "Neutralizing Value", concentration of calcium in lime material, 0 - 100, Ground limestone = 50
	RN.HerbicideKgPerHa =               2;

	RN.pigSlurryFraction =            0.5;		-- fraction of Farm slurry originating from pigs. The rest is cow slurry.
	RN.pigManureFraction =            0.5;		-- fraction of manure spread on fields originating from pigs
	RN.organicFertilizerFraction =    0.2;		-- fraction of fertilizer spread on fields originating from organic sources
	RN.liqfertDilutionFactor =         20;		-- 1 Liter of liquid fertilizer is diluted to 20 liter of solution
	RN.liqfertLiquidReductionFactor = 0.1;		-- liquid fertilizer is needed in smaller dosis due to better uptake
	RN.herbicideDilutionFactor =      200;		-- 1 liter of herbicide to 200 liter of water

-- Seeders and planters, update values to your equipment

	RN.grainseederWorkWidth  =          4;		-- m
	RN.grainseederWorkingSpeed =       15;		-- kph
	RN.grainseederSeedCapacity =     1500; 		-- L
	RN.rowplanterWorkWidth =            6;		-- m
	RN.rowplanterWorkingSpeed =        15;		-- kph
	RN.rowplanterSeedCapacity =    	 2600;  	-- L
	RN.potatoplanterWorkWidth =         6;		-- m
	RN.potatoplanterWorkingSpeed =     12;		-- kph
	RN.potatoplanterSeedCapacity =   9020;		-- L

-- Harvesters, update values to your equipment
	
	RN.grainHeaderwidth =             7.6; 		-- m 
	RN.grainWorkingspeed =             10;		-- kph 
	RN.rowgrainHeaderwidth =            6; 		-- m 
	RN.rowgrainWorkingspeed =          10;		-- kph 	
	RN.potatoHeaderwidth =            3.0; 		-- m 
	RN.potatoWorkingspeed =            12;		-- kph 		
	RN.sugarbeetHeaderwidth =         5.4; 		-- m 
	RN.sugarbeetWorkingspeed =         12;		-- kph 
		
	
-- Field prices

	RN.annualLoanInterest =      4;				-- Annual interest rate on loans
	RN.loanMax =           3000000;				-- Max loan
	RN.pricePerHa =          11532; 			-- GEO purchase price of farmland per hectare
	RN.rentPricePerHa = 0.033 * RN.pricePerHa;	-- GEO rent price of farmland per hectare

	RN.rentedFields =            { 5, 9, 14, 16, 20, 23, 28, 32, 38, 43, 49, 56, 60, 67, 73, 84}; -- Numbers for fields to be rentable


-- Commodity prices

	RN.commodity =               {"FUEL", "WATER", "SEEDS", "DIESEL", "FERTILIZER", "LIQUIDFERTILIZER", "PIGFOOD", "FORAGE_MIXING", "LIME", "HERBICIDE"};
	RN.commodityDensity =        {  0.75,   1.00,    0.32,     0.84,        0.8,            0.9,           0.65,        0.22,        1.2,         1.0  };
	RN.commodityPricePer100kg =  {102.85,  10.00,  113.05,   106.42,      62.53,          62.53,          55.92,       47.27,        5.36,     1026.0  }; 	-- GEO 
	RN.commodityPriceVariation = 10; 	-- price fluctuation in percentage

	
-- Round bale prices

	RN.roundBales =              {"ROUNDBALE", "ROUNDBALE_GRASS", "ROUNDBALE_DRYGRASS", "ROUNDBALE_WHEAT", "ROUNDBALE_BARLEY" };
	RN.roundBaleMass =           {     640,           1840,                 640,               520,               520         };		-- kg
	RN.roundBaleVolume =         {    4000,           4000,                4000,              4000,              4000         };		-- Liters
	RN.roundBalePricePer100kg =  {   11.55,           5.00,               11.55,              7.47,              7.47         };        -- GEO pricePer100kg


-- Square bale prices

	RN.squareBales =             {"SQUAREBALE", "SQUAREBALE_WHEAT", "SQUAREBALE_BARLEY"};
	RN.squareBaleMass =          {     640,            520,                   520      };		-- kg
	RN.squareBaleVolume =        {    4000,           4000,                  4000      };		-- Liters
	RN.squareBalePricePer100kg = {   11.55,           7.47,                  7.47      };       -- GEO pricePer100kg


-- Organic materials

	RN.organicMaterials =        {"MANURE", "LIQUIDMANURE", "DIGESTATE"};
	RN.organicPrices =           {  0.033,       0.033,        0.033   };  	-- GEO pricePerLiter

-- Store objects

	RN.storeBigbags =            {"bigbagpigfood", "bigbaghorsefood", "bigbagchickenfood", "bigbagseeds", "bigbagfertilizer", "bigbaglime"};
	RN.storeObjectsId =          {   407,              408,               409,               410,             411,              412       };
	RN.bigbagVolume =            {  1000,             1000,              1000,              1000,            1000,			   2000       };	-- Liters

	RN.storePallets =            {"Liq_fertilizer", "Herbicide", "Tree_sapling", "Poplar_sapling", "Sugarcane"   };
	RN.storePalletsId =          {     413,             414,          415,            416,             417       };
	RN.storePalletVolume =       {    2000,            2000,           20,           2000,            2000       };		-- Liters
	RN.treeSaplingsUnitPrice = 1.0;

	RN.storeBales =              {"SQUARE STRAW", "SQUARE HAY", "ROUND SILAGE", "ROUND STRAW", "ROUND HAY"};
	RN.storeBalesId =            {     421,              422,        423,            424,         425     };
	RN.storeBalesMass =          {     520,              640,       1840,            520,         640     }; 	-- kg
	RN.storeBalesVolume =        {    4000,             4000,       4000,           4000,        4000     };	-- Liters
    RN.storeBalesPricePer100kg = {    7.47,            11.55,       5.00,           7.47,       11.55     };	-- GEO price per 100 kg


	RN.animalTypes =             { "PIG",            "COW",        "SHEEP",       "CHICKEN",   "HORSE"    };	

-- Animal products

	RN.animalProduct =              {"MILK", "WOOL",   "EGG"};
    RN.animalProductDensity =       {1.025,   0.375,    1.2 };	--kg/L
	RN.animalProductPricePer100kg = {43.78,  152.78, 157.43 };	-- GEO price per 100 kg

-- Animal care

	RN.pigs.color =                {     "RED",         "WHITE",          "BLACK_WHITE",         "BLACK"     };
	RN.pigs.type =                 {  "Standard",     "Sows+Piglets",      "Growers",          "Finishers"   };
	RN.pigs.fillType =             {      73,              74,                 75,                  76       };
	RN.pigs.penCapacity =          {     100,             200,                200,                 200       };	-- default values overwritten later
    RN.pigs.reeringGamedays =      {       6,               6,                  6,                   6       };
	RN.pigs.gamedaysInPen =        {       6,               2,                  1,                   1       }; -- number of gamedays the offspring stays in the pen
	RN.pigs.birthingAnimals =      {       6,              48,                  0,                   0       };	-- number of breeders 
	RN.pigs.litterSize =           {      13,              13,                 13,                  13       };
	RN.pigs.growers =              {       0,               0,                104,                 104       }; -- number of non-breeding growers
	RN.pigs.matureWeight =         {     180,             180,                180,                 180       };	-- kg
	RN.pigs.buyWeight =            {     180,               1,                 21,                  47       }; -- kg
	RN.pigs.sellWeight =           {      81,              21,                 47,                  81       };	-- kg
    RN.pigs.pricePer100kg =        {      77,              77,                 77,                  77       };	-- GEO sell price per 100 kg live weight
	RN.pigs.transportFee =         {      10,               0,                  0,                   0       };	-- transport fee per animal
    RN.pigs.matureBuyFactor =      {     1.5,             1.5,                  0,                   0       };	-- Purchase price divided by sell price
	RN.pigs.matureStrawPerDay =    {     2.0,             2.0,                  0,                   0       }; -- kg
	RN.pigs.growerStrawPerDay =    {     0.9,             0.5,               0.75,                 1.5       }; -- kg
	RN.pigs.matureWaterPerDay =    {    17.5,            17.5,                  0,                   0       }; -- L
	RN.pigs.growerWaterPerDay =    {     4.0,             1.0,                4.0,                 7.0       }; -- L
	RN.pigs.bowserWaterFraction =  {     0.1,             0.1,                0.1,                 0.1       };
	RN.pigs.matureFeedPerDay =     {     3.3,             3.3,                  0,                   0       }; -- kg
	RN.pigs.growerFeedPerDay =     {     1.9,             0.4,                1.8,                 3.7       }; -- kg
	RN.pigs.troughFeedFraction =   {     1.0,             1.0,                1.0,                 1.0       };
	RN.pigs.matureManurePerDay =   {    11.7,            11.7,                  0,                   0       }; -- kg
	RN.pigs.growerManurePerDay =   {     4.0,             0.6,                3.7,                 7.9       }; -- kg
	RN.pigs.matureSlurryPerWater = {    0.85,            0.85,                  0,                   0       }; -- Liquid manure as fraction of water intake
	RN.pigs.growerSlurryPerWater = {     0.9,             0.9,                0.9,                 0.9       }; -- Liquid manure as fraction of water intake
	
	RN.cows.color1 =               {   "BROWN",       "BROWN_WHITE",         "BLACK",       "BLACK_WHITE"    };
	RN.cows.color2 =               {"BRAHMAN_BROWN", "BRAHMAN_WHITE", "BRAHMAN_LIGHT_BROWN","BRAHMAN_GREY"   };
	RN.cows.type =                 {  "Standard",       "Milkers",          "First years",  "Second years"   };
	RN.cows.fillType1 =            {      61,              62,                 63,                  64       };
	RN.cows.fillType2 =            {      65,              66,                 67,                  68       };
	RN.cows.penCapacity =          {      50,              50,                 50,                  50       };	-- default values overwritten later
    RN.cows.reeringGamedays =      {      12,              12,                 12,                  12       };
	RN.cows.gamedaysInPen =        {      12,              12,                 12,                  12       }; -- number of gamedays the offspring stays in the pen
    RN.cows.birthingAnimals =      {      20,              20,                  1,                   0       };	-- number of cows (mature birthgiving animals)
	RN.cows.litterSize =           {       1,               0,                 20,                   0       };
	RN.cows.growers =              {       0,               0,                  0,                  16       }; -- number of non-breeding growers
	RN.cows.matureWeight =         {     640,             640,                640,                 640       };	-- kg
	RN.cows.buyWeight =            {     640,             640,                 20,                 290       }; -- kg
	RN.cows.sellWeight =           {     291,             640,                290,                 545       };	-- kg
    RN.cows.pricePer100kg =        {     107,             107,                107,                 107       };	-- GEO sell price per 100 kg live weight
	RN.cows.transportFee =         {      15,              15,                  0,                   0       };	-- transport fee per animal
    RN.cows.matureBuyFactor =      {     1.5,             1.5,                  0,                   0       };	-- Purchase price divided by sell price
	RN.cows.matureStrawPerDay =    {     1.4,             1.4,                  0,                   0       }; -- kg
	RN.cows.growerStrawPerDay =    {     0.8,               0,               0.78,                 1.4       }; -- kg
	RN.cows.matureWaterPerDay =    {     110,             110,                  0,                   0       }; -- L
	RN.cows.growerWaterPerDay =    {    13.6,               0,               13.6,                30.0       }; -- L
	RN.cows.bowserWaterFraction =  {     0.1,             0.1,                0.1,                 0.1       };
	RN.cows.matureFeedPerDay =     {      44,              44,                  0,                   0       }; -- kg
	RN.cows.growerFeedPerDay =     {    14.5,               0,               14.5,                31.2       }; -- kg	
	RN.cows.troughFeedFraction =   {    0.25,            0.25,               0.25,                0.25       };
	RN.cows.matureManurePerDay =   {    52.3,            52.3,                  0,                   0       }; -- kg
	RN.cows.growerManurePerDay =   {    12.6,               0,               12.6,                  35       }; -- kg
	RN.cows.matureSlurryPerWater = {    0.75,            0.75,                  0,                   0       }; -- Liquid manure as fraction of water intake
	RN.cows.growerSlurryPerWater = {     0.9,             0.9,                0.9,                 0.9       }; -- Liquid manure as fraction of water intake
	RN.cows.milkPerYear =          {    7370,            7370,                  0,                   0       }; -- GEO kg/year
	
	RN.sheep.color =               {   "WHITE",         "BROWN",          "BLACK_WHITE",          "BLACK"    };
	RN.sheep.type =                {  "Standard",     "Preweaned",          "Growers",          "Replacers"  };
	RN.sheep.fillType =            {      69,              70,                 71,                  72       };
	RN.sheep.penCapacity =         {      80,             250,                 80,                  80       };	-- default values overwritten later
    RN.sheep.reeringGamedays =     {      12,              12,                 12,                  12       };
	RN.sheep.gamedaysInPen =       {      12,               4,                  4,                   4       }; -- number of gamedays the offspring stays in the pen
    RN.sheep.birthingAnimals =     {      24,             120,                  0,                   0       };	-- number of ewes (mature birthgiving animals)
	RN.sheep.litterSize =          {    1.25,            1.25,                  0,                   0       };
	RN.sheep.growers =             {       0,               0,                 50,                  10       }; -- number of non-breeding growers
	RN.sheep.matureWeight =        {     120,             120,                120,                 120       };	-- kg
	RN.sheep.buyWeight =           {     120,               5,                 21,                  44       }; -- kg
	RN.sheep.sellWeight =          {      66,              21,                 44,                  66       };	-- kg
    RN.sheep.pricePer100kg =       {      80,              80,                 80,                  80       };	-- GEO sell price per 100 kg live weight
	RN.sheep.transportFee =        {      10,               0,                  0,                   0       };	-- transport fee per animal
    RN.sheep.matureBuyFactor =     {     1.5,             1.5,                  0,                   0       };	-- Purchase price divided by sell price
	RN.sheep.matureWaterPerDay =   {    4.75,            4.75,                  0,                   0       }; -- L
	RN.sheep.growerWaterPerDay =   {    2.25,            0.75,                3.0,                 4.0       }; -- L
	RN.sheep.bowserWaterFraction = {     0.1,             0.1,                0.1,                 0.1       };
	RN.sheep.matureFeedPerDay =    {    10.5,            10.5,                  0,                   0       }; -- kg
	RN.sheep.growerFeedPerDay =    {     2.2,             1.2,                3.1,                 5.1       }; -- kg
	RN.sheep.troughFeedFraction =  {    0.17,            0.17,               0.17,                0.17       };
	RN.sheep.grassFeedFraction =   {     0.5,             0.5,                0.5,                 0.5       }; -- fraction of trough feed which is grass
	RN.sheep.matureWoolPerYear =   {     8.2,             8.2,                  0,                   0       }; -- kg
	RN.sheep.growerWoolPerYear =   {       0,               0,                  0,                   0       }; -- kg
	
	RN.chicken.color =             {   "BLACK",          "WHITE",            "BROWN",           "ROOSTER"    };
	RN.chicken.type =              {  "Standard",       "Hatchers",          "Layers",          "Broilers"   };
	RN.chicken.fillType =          {      77,              78,                 79,                  80       };	
	RN.chicken.penCapacity =       {     100,             500,                500,                 500       };	-- default values overwritten later
    RN.chicken.reeringGamedays =   {      12,              12,                 12,                  12       };
	RN.chicken.gamedaysInPen =     {       2,               4,                 12,                   4       }; -- number of gamedays the offspring stays in the pen 
	RN.chicken.birthingAnimals =   {      42,               0,                400,                   0       };	-- number of hens (mature birthgiving animals)
	RN.chicken.litterSize =        {       7,               0,                  0,                   0       };
	RN.chicken.growers =           {       0,             100,                  0,                 400       }; -- number of non-breeding growers	RN.chicken.StartWeight =       {   0.065,           0.065,                1.4,                 120       };	-- kg
	RN.chicken.matureWeight =      {     2.6,             2.6,                2.6,                 2.6       };	-- kg
	RN.chicken.buyWeight =         {     2.6,            0.05,                1.4,                0.05       }; -- kg
	RN.chicken.sellWeight =        {     2.6,             1.4,                2.0,                 2.6       };	-- kg
    RN.chicken.pricePer100kg =     {      88,              88,                 88,                  88       };	-- GEO sell price per 100 kg live weight
	RN.chicken.transportFee =      {     0.1,               0,                  0,                 0.1       };	-- transport fee per animal
    RN.chicken.matureBuyFactor =   {     1.5,               0,                  0,                   0       };	-- Purchase price divided by sell price
	RN.chicken.matureFeedPerDay =  {    0.11,               0,               0.11,                   0       }; -- kg
	RN.chicken.growerFeedPerDay =  {    0.11,            0.05,                  0,                0.11       }; -- kg
	RN.chicken.troughFeedFraction ={     1.0,             1.0,                1.0,                 1.0       };
	RN.chicken.matureEggsPerYear=  {     275,               0,                275,                   0       };
	RN.chicken.growerEggsPerYear=  {       0,               0,                  0,                   0       };

	RN.horses.fillType =           { 53, 54, 55, 56, 57, 58, 59, 60 };
	RN.horses.penCapacity =        { 2, 8, 12, 16};
	RN.horses.numberOfMatureAnimals =       8;
	RN.horses.beddingStrawIntensity =     0.1;	-- varies from nothing to one big bale per month per horse.
	RN.horses.waterIntakePerKg =        0.084;	-- Water intake per day per kg body weight
	RN.horses.feedPerHorsePerDayPerKg = 0.025;	-- kg feed /kg body weight
	RN.horses.matureWeight =              650; 	-- kg
	RN.horses.buyPrice =                 3000;  -- €/$/£
	RN.horses.sellPrice =               20000;  -- €/$/£
	RN.horses.transportFee =               50; 	-- €/$/£
							
--	RN.horses.beddingStrawPerHorsePerMonth = RN.horses.beddingStrawIntensity * RN.roundBaleVolume[4];
--	RN.horses.beddingStrawPerHorsePerDay = RN.horses.beddingStrawPerHorsePerMonth / 30;
--	RN.horses.waterPerHorsePerRealDay = RN.horses.matureWeight * RN.horses.waterIntakePerKg;
--	RN.horses.feedMassPerHorsePerRealDay = RN.horses.matureWeight * RN.horses.feedPerHorsePerDayPerKg;
	
	
	RN.horses.manurePerDay =                0;	-- L, is probably not used	
	RN.horses.milkPerDay =                  0; 	-- L, is probably not used
	RN.horses.palletsPerDay =               0; 	-- is probably not used	


	RN.feedSpillageFraction =            0.05;	-- fraction of feed spilled in front of trough default: 0.05
	RN.chicken.LiterPerEgg =             0.05;	-- Liter/eggs
	RN.sheep.woolVolumePerPallet =       1000;	-- Liters/pallet
	RN.chicken.eggVolumePerPallet =        75;	-- Liters/pallet
	
	print("\n============================ FS19_RealLifeNumbers_US_Heartland by ArmChairFarming ============================\n");
	print("\nFS19_RealLifeNumbers: RealNumbersInitialization active");


	RN.playTime = nil;
	RN.randomness = 0;

	local savegameDirectory = g_currentMission.missionInfo.savegameDirectory;	-- works except when a new map is opened the first time
	if savegameDirectory ~= nil then
		local careerFile = savegameDirectory.."/careerSavegame.xml";
		if isDebug2 then print("careerFile : "..tostring(careerFile)); end;
		local xmlFile = loadXMLFile("careerFile", careerFile);
		local key = string.format("careerSavegame.statistics");
		if not hasXMLProperty(xmlFile, "careerSavegame") then
			if isDebug2 then print("Does not have XMLproperty"); end;
		end;
		RN.playTime = 1000 * getXMLFloat(xmlFile, "careerSavegame.statistics.playTime");
	end;

	if RN.playTime == nil then
		if isDebug2 then print("playTime is nil") end;
		RN.randomness = 0;
	else
		local randomSeednumber = math.randomseed(RN.playTime);
		if isDebug2 then print("playTime is "..RN.playTime/1000); end;
		if isDebug2 then print("random number is "..math.random()); end;
		RN.randomness = 1.
	end;



end;


function RealNumbersInitialization:keyEvent(unicode, sym, modifier, isDown)
end;
function RealNumbersInitialization:update(dt)
end;
function RealNumbersInitialization:draw()
end;
function RealNumbersInitialization:deleteMap()
end;
function RealNumbersInitialization:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersInitialization);
